@@ -21,7 +21,6 @@ You should have received a copy of the GNU Lesser General Public License
 along with pyscard; if not, write to the Free Software
 Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 """
-from __future__ import print_function
 from smartcard.Exceptions import InvalidATRMaskLengthException
 from smartcard.System import readers
 from smartcard.util import toHexString
@@ -51,6 +50,9 @@ class CardType(object):
 class AnyCardType(CardType):
     """The AnyCardType matches any card."""
 
+    def __init__(self):
+        super().__init__()
+
     def matches(self, atr, reader=None):
         """Always returns true, i.e. AnyCardType matches any card.
 
@@ -68,6 +70,7 @@ class ATRCardType(CardType):
         @param mask:   an optional mask to be applied to the ATR for
             L{CardType} matching default is None
         """
+        super().__init__()
         self.atr = list(atr)
         self.mask = mask
         if mask is None:
